@@ -3,16 +3,21 @@ from dataclasses import dataclass
 from mypy.nodes import (
     CallExpr,
     DictionaryComprehension,
+    Expression,
     ForStmt,
     GeneratorExpr,
     MemberExpr,
     NameExpr,
     Node,
     TupleExpr,
-    Var,
 )
 
-from refurb.checks.common import check_for_loop_like, is_name_unused_in_contexts, stringify
+from refurb.checks.common import (
+    check_for_loop_like,
+    is_mapping,
+    is_name_unused_in_contexts,
+    stringify,
+)
 from refurb.error import Error
 
 
@@ -66,12 +71,10 @@ def check_dict_items_call(
         case (
             TupleExpr(items=[NameExpr() as key, NameExpr() as value]),
             CallExpr(
-                callee=MemberExpr(
-                    expr=NameExpr(node=Var(type=ty)) as dict_expr,
-                    name="items",
-                )
+                callee=MemberExpr(expr=dict_expr, name="items"),
+                args=[],
             ),
-        ) if str(ty).startswith("builtins.dict["):
+        ) if is_mapping(dict_expr):
             check_unused_key_or_value(key, value, contexts, errors, dict_expr)
 
 
@@ -80,7 +83,7 @@ def check_unused_key_or_value(
     value: NameExpr,
     contexts: list[Node],
     errors: list[Error],
-    dict_expr: NameExpr,
+    dict_expr: Expression,
 ) -> None:
     if is_name_unused_in_contexts(key, contexts):
         msg = f"Key is unused, use `for {stringify(value)} in {stringify(dict_expr)}.values()` instead"  # noqa: E501
