@@ -851,6 +851,11 @@ def _(node: TypeAliasExpr, visitor: TraverserVisitor) -> None:
     return visitor.visit_type_alias_expr(node)
 
 
+@accept.register
+def _(node: TypeAliasStmt, visitor: TraverserVisitor) -> None:
+    return visitor.visit_type_alias_stmt(node)
+
+
 @accept.register
 def _(node: NamedTupleExpr, visitor: TraverserVisitor) -> None:
     return visitor.visit_namedtuple_expr(node)
